@@ -15,8 +15,8 @@
 
 #if defined(_MSC_VER)
 // suppress warning about non-exported base classes
-#pragma warning (disable : 4251)
-#pragma warning (disable : 4275)
+#    pragma warning(disable : 4251)
+#    pragma warning(disable : 4275)
 #endif
 
 OPENEXR_IMF_INTERNAL_NAMESPACE_SOURCE_ENTER
@@ -24,40 +24,40 @@ OPENEXR_IMF_INTERNAL_NAMESPACE_SOURCE_ENTER
 using namespace OPENEXR_IMF_INTERNAL_NAMESPACE;
 
 template <>
-IMF_EXPORT const char *
+IMF_EXPORT const char*
 EnvmapAttribute::staticTypeName ()
 {
     return "envmap";
 }
 
-
 template <>
 IMF_EXPORT void
-EnvmapAttribute::writeValueTo (OPENEXR_IMF_INTERNAL_NAMESPACE::OStream &os, int version) const
+EnvmapAttribute::writeValueTo (
+    OPENEXR_IMF_INTERNAL_NAMESPACE::OStream& os, int version) const
 {
     unsigned char tmp = _value;
-    Xdr::write <StreamIO> (os, tmp);
+    Xdr::write<StreamIO> (os, tmp);
 }
 
-
 template <>
 IMF_EXPORT void
-EnvmapAttribute::readValueFrom (OPENEXR_IMF_INTERNAL_NAMESPACE::IStream &is, int size, int version)
+EnvmapAttribute::readValueFrom (
+    OPENEXR_IMF_INTERNAL_NAMESPACE::IStream& is, int size, int version)
 {
     unsigned char tmp;
-    Xdr::read <StreamIO> (is, tmp);
+    Xdr::read<StreamIO> (is, tmp);
     _value = Envmap (tmp);
 }
 
 template <>
 IMF_EXPORT void
-EnvmapAttribute::copyValueFrom (const OPENEXR_IMF_INTERNAL_NAMESPACE::Attribute &other)
+EnvmapAttribute::copyValueFrom (
+    const OPENEXR_IMF_INTERNAL_NAMESPACE::Attribute& other)
 {
-    _value = cast(other).value();
-
+    _value = cast (other).value ();
 }
 
-template class IMF_EXPORT_TEMPLATE_INSTANCE TypedAttribute<OPENEXR_IMF_INTERNAL_NAMESPACE::Envmap>;
+template class IMF_EXPORT_TEMPLATE_INSTANCE
+    TypedAttribute<OPENEXR_IMF_INTERNAL_NAMESPACE::Envmap>;
 
-
-OPENEXR_IMF_INTERNAL_NAMESPACE_SOURCE_EXIT 
+OPENEXR_IMF_INTERNAL_NAMESPACE_SOURCE_EXIT
