@@ -12,11 +12,10 @@ uint64_t internal_rle_compress (
     void* out, uint64_t outbytes, const void* src, uint64_t srcbytes);
 
 void internal_zip_deconstruct_bytes (
-    uint8_t*       scratch,
-    const uint8_t* source,
-    uint64_t       count);
+    uint8_t* scratch, const uint8_t* source, uint64_t count);
 
-void internal_zip_reconstruct_bytes (uint8_t* out, uint8_t* scratch_source, uint64_t count);
+void internal_zip_reconstruct_bytes (
+    uint8_t* out, uint8_t* scratch_source, uint64_t count);
 
 exr_result_t internal_exr_apply_rle (exr_encode_pipeline_t* encode);
 
